<?php

namespace Drupal\Tests\config_overlay\Functional;

use Drupal\Core\Config\StorageInterface;

/**
 * Tests installation of the Umami profile with Configuration Overlay.
 *
 * @group config_overlay
 */
class ConfigOverlayDemoUmamiTest extends ConfigOverlayProfileTestBase {

  /**
   * {@inheritdoc}
   */
  protected $profile = 'demo_umami';

  /**
   * {@inheritdoc}
   */
  protected function prepareEnvironment() {
    parent::prepareEnvironment();

    /* @see https://www.drupal.org/project/drupal/issues/2990234 */
    $this->translationFilesDirectory = $this->publicFilesDirectory . '/translations';
    mkdir($this->translationFilesDirectory, 0777, TRUE);

    // Prepare a translation file to avoid attempting to download a translation
    // file from the actual translation server during the test.
    file_put_contents("{$this->root}/{$this->translationFilesDirectory}/drupal-8.0.0.es.po", '');
  }

  /**
   * {@inheritdoc}
   */
  protected function getExpectedConfig() {
    $expected_config = parent::getExpectedConfig();

    unset($expected_config[StorageInterface::DEFAULT_COLLECTION]['filter.format.restricted_html']['roles']);

    return $expected_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getOverriddenConfig() {
    $overridden_config = parent::getOverriddenConfig();

    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['core.extension']['theme'] = [
      'seven' => 0,
      'umami' => 0,
    ];

    // The system site configuration is overridden by the test, so make it match
    // the values given in Umami's version of the file.
    /* @see \Drupal\Tests\config_overlay\Functional\ConfigOverlayTestingTest::getOverriddenConfig() */
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['system.site']['page']['front'] = '/node';

    /* @see demo_umami_form_install_configure_submit() */
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['contact.form.feedback'] = [
      'recipients' => ['simpletest@example.com'],
    ];

    // Add text formats with a roles property.
    /* @see https://www.drupal.org/project/drupal/issues/3167198 */
    /* @see \Drupal\Tests\config_overlay\Functional\ConfigOverlayDemoUmamiTest::getExpectedConfig() */
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['filter.format.restricted_html'] = [];

    return $overridden_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getModules() {
    $modules = parent::getModules();
    $modules += [
      'automated_cron' => 0,
      'big_pipe' => 0,
      'block' => 0,
      'block_content' => 0,
      'breakpoint' => 0,
      'ckeditor' => 0,
      'color' => 0,
      'config' => 0,
      'config_translation' => 0,
      'contact' => 0,
      'content_moderation' => 0,
      'contextual' => 0,
      'datetime' => 0,
      'dblog' => 0,
      'demo_umami_content' => 0,
      'dynamic_page_cache' => 0,
      'editor' => 0,
      'field' => 0,
      'field_ui' => 0,
      'file' => 0,
      'filter' => 0,
      'help' => 0,
      'history' => 0,
      'image' => 0,
      'language' => 0,
      'layout_builder' => 0,
      'layout_discovery' => 0,
      'link' => 0,
      'locale' => 0,
      'media' => 0,
      'media_library' => 0,
      'menu_link_content' => 0,
      'menu_ui' => 0,
      'node' => 0,
      'options' => 0,
      'page_cache' => 0,
      'path' => 0,
      'quickedit' => 0,
      'rdf' => 0,
      'responsive_image' => 0,
      'search' => 0,
      'shortcut' => 0,
      'taxonomy' => 0,
      'text' => 0,
      'toolbar' => 0,
      'tour' => 0,
      'views_ui' => 0,
      'workflows' => 0,
      'content_translation' => 10,
      'views' => 10,
    ];
    return $modules;
  }

}
