<?php

namespace Drupal\Tests\config_overlay\Functional;

use Drupal\Core\Config\StorageInterface;

/**
 * Tests the Testing multilingual profile with Configuration Overlay.
 *
 * @group config_overlay
 */
class ConfigOverlayTestingMultilingualTest extends ConfigOverlayProfileTestBase {

  /**
   * {@inheritdoc}
   */
  protected $profile = 'testing_multilingual';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected $collections = [
    StorageInterface::DEFAULT_COLLECTION,
    'language.de',
    'language.es',
  ];

  /**
   * {@inheritdoc}
   */
  protected function prepareEnvironment() {
    parent::prepareEnvironment();

    /* @see https://www.drupal.org/project/drupal/issues/2990234 */
    $this->translationFilesDirectory = $this->publicFilesDirectory . '/translations';
    mkdir($this->translationFilesDirectory, 0777, TRUE);

    // Prepare translation files to avoid attempting to download translation
    // files from the actual translation server during the test. The files
    // contain an actual translation to test that translations for configuration
    // are imported correctly.
    $po_de = <<<PO
msgid ""
msgstr ""

msgid "User account"
msgstr "Benutzerkonto"
PO;
    file_put_contents("{$this->root}/{$this->translationFilesDirectory}/drupal-8.0.0.de.po", $po_de);
    $po_fr = <<<PO
msgid ""
msgstr ""

msgid "User account"
msgstr "Cuenta de usuario"
PO;
    file_put_contents("{$this->root}/{$this->translationFilesDirectory}/drupal-8.0.0.es.po", $po_fr);
  }

  /**
   * {@inheritdoc}
   */
  protected function getOverriddenConfig() {
    $overridden_config = parent::getOverriddenConfig();

    /* @see \Drupal\language\Entity\ConfigurableLanguage::postSave() */
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['language.negotiation'] = [
      'url' => [
        'prefixes' => [
          'de' => 'de',
          'es' => 'es',
        ],
        'domains' => [
          'de' => '',
          'es' => '',
        ],
      ],
    ];

    // Add overrides for translated configuration.
    /* @see \Drupal\Tests\config_overlay\Functional\ConfigOverlayTestingLanguageTest::prepareEnvironment() */
    $overridden_config['language.de']['core.entity_view_mode.user.full'] = [
      'label' => 'Benutzerkonto',
    ];
    $overridden_config['language.es']['core.entity_view_mode.user.full'] = [
      'label' => 'Cuenta de usuario',
    ];

    return $overridden_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getModules() {
    $modules = parent::getModules();
    $modules += [
      'field' => 0,
      'file' => 0,
      'language' => 0,
      'locale' => 0,
      'tour' => 0,
    ];
    return $modules;
  }

}
