<?php

namespace Drupal\Tests\config_overlay\Functional\ExistingConfig;

use Drupal\Core\Archiver\ArchiveTar;
use Drupal\Core\Config\StorageInterface;
use Drupal\FunctionalTests\Installer\InstallerExistingConfigTestBase;
use Drupal\Tests\config_overlay\Functional\ConfigOverlayFunctionalTestTrait;

/**
 * Provides a base class for testing existing configuration.
 */
abstract class ConfigOverlayExistingConfigTestBase extends InstallerExistingConfigTestBase {

  use ConfigOverlayFunctionalTestTrait {
    getExpectedConfig as traitGetExpectedConfig;
    getOverriddenConfig as traitGetOverriddenConfig;
  }

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['config_overlay'];

  /**
   * A list of collections for this test's configuration.
   *
   * @var string[]
   */
  protected $collections = [StorageInterface::DEFAULT_COLLECTION];

  /**
   * {@inheritdoc}
   */
  protected function getExpectedConfig() {
    $expected_config = $this->traitGetExpectedConfig();

    // The existing configuration will not have a default configuration hash
    // after importing.
    foreach ($this->getExistingConfigNames() as $config_name) {
      unset($expected_config[StorageInterface::DEFAULT_COLLECTION][$config_name]['_core']);
    }

    return $expected_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getOverriddenConfig() {
    $overridden_config = $this->traitGetOverriddenConfig();

    // Tests based on InstallerTestBase do not call
    // BrowserTestBase::installDrupal() and, by extension,
    // FunctionalTestSetupTrait::initConfig(). The change to the 'system.mail'
    // configuration is still performed, however.
    /* @see \Drupal\FunctionalTests\Installer\InstallerTestBase::setUp() */
    unset(
      $overridden_config[StorageInterface::DEFAULT_COLLECTION]['system.logging'],
      $overridden_config[StorageInterface::DEFAULT_COLLECTION]['system.performance']
    );

    // The existing configuration should always be overridden.
    foreach ($this->getExistingConfigNames() as $config_name) {
      $overridden_config[StorageInterface::DEFAULT_COLLECTION] += [
        $config_name => [],
      ];
    }

    return $overridden_config;
  }

  /**
   * Gets a list of configuration names of the existing configuration.
   *
   * @return string[]
   *   A list of configuration names.
   *
   * @see \Drupal\FunctionalTests\Installer\InstallerExistingConfigTestBase::prepareEnvironment()
   */
  protected function getExistingConfigNames() {
    $archiver = new ArchiveTar($this->getConfigTarball(), 'gz');
    $list = $archiver->listContent();
    $config_names = [];
    if (is_array($list)) {
      foreach ($list as $file) {
        $config_names[] = basename($file['filename'], '.yml');
      }
    }
    return $config_names;
  }

}
