<?php

namespace Drupal\Tests\config_overlay\Functional\ExistingConfig;

use Drupal\Core\Config\StorageInterface;

/**
 * Tests installation of the Minimal profile with Configuration Overlay.
 *
 * @group config_overlay
 */
class ConfigOverlayMinimalExistingConfigTest extends ConfigOverlayExistingConfigTestBase {

  /**
   * {@inheritdoc}
   */
  protected $profile = 'minimal';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function getConfigTarball() {
    // This tarball contains the following configuration files:
    // - core.extension.yml: With the extensions given by the Minimal profile
    //   plus Config Overlay.
    // - system.date.yml: To set the default timezone to UTC.
    // - system.site.yml: To set the site UUID, name and mail.
    return __DIR__ . '/../../../fixtures/config_install/minimal_config_install.tar.gz';
  }

  /**
   * {@inheritdoc}
   */
  protected function getOverriddenConfig() {
    $overridden_config = parent::getOverriddenConfig();

    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['system.date']['timezone']['default'] = 'UTC';
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['system.site']['name'] = 'Site with Minimal profile and Config Overlay';
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['system.site']['mail'] = 'admin@example.com';

    // Note that the anonymous and authenticated roles are not overridden, even
    // though they are changed when installing Node module, as the subsequent
    // configuration import will revert the roles back to the original state.
    /* @see node_install() */

    return $overridden_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getModules() {
    $modules = parent::getModules();
    $modules += [
      'block' => 0,
      'dblog' => 0,
      'dynamic_page_cache' => 0,
      'field' => 0,
      'filter' => 0,
      'node' => 0,
      'page_cache' => 0,
      'text' => 0,
    ];
    return $modules;
  }

}
